/**
 * Copyright (c) 2007 Colony Project
 * 
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 **/


/**
 * @file battery.h
 * @brief Definitions for checking battery voltage.
 * 
 * Contains definitions for checking the voltage of the 
 * battery.
 *
 * @author Colony Project, CMU Robotics Club
 **/

#ifndef _BATTERY_H_
#define _BATTERY_H_

/**
 * @addtogroup battery
 * @{
 **/

/** @brief Normal battery voltage. (6 V) **/
#define BATTERY_NORMALV 154
/** @brief Charging battery voltage. (7 V) **/
#define BATTERY_CHARINGV 179
/** @brief Low battery voltage. ( < 6 V) **/
#define BATTERY_LOWV 152

/** @brief Read the battery voltage. **/
int battery8(void);
/** @brief Read the battery voltage in deciVolts. **/
int battery(void);
/** @brief Check if the battery is low. **/
char battery_low(void);
/** @brief Get an average battery voltage reading. **/
int battery8_avg(int n_samples);

/** @} **/ //end addtogroup

#endif

