/**
 * 
 * @file encoders.h
 * @brief Contains functions for reading encoder values.
 *
 * Contains high and low level functions for reading encoders
 * including reading out total distance covered, and 
 * eventually velocity.
 *	
 * @author Colony Project, CMU Robotics Club
*/

/**
 * @addtogroup encoders
 * @{
 **/

#ifndef __ENCODERS_H__
#define __ENCODERS_H__


#ifndef LEFT
	/** @brief Left wheel **/
	#define LEFT 0
#endif
#ifndef RIGHT
	/** @brief Right wheel **/
	#define RIGHT 1
#endif

/** @brief Magnet misaligned - likely distance from encoder problem. **/
#define ENCODER_MAGNET_FAILURE 1025
/** @brief Encoder misaligned - likely on XY plane. **/
#define ENCODER_MISALIGNED 1027
/** @brief Not enough time has passed - encoders not initialized in hardware. **/
#define ENCODER_DATA_NOT_READY 1026

/** @brief delay_ms argument after a full read is complete **/
#define ENCODER_DELAY 20

//Data invalid flags (hardware failure):
#define OCF _BV(4)
#define COF _BV(3)

//Data invalid alarm (May be invalid):
#define LIN _BV(2)

#define MagINCn _BV(1)
#define MagDECn _BV(0)

/** @brief Buffer size **/
#define BUFFER_SIZE 23

/** @brief Initialize encoders. **/
void encoders_init(void);
/** @brief Read instantaneous encoder value. **/
int encoder_read(char encoder);

/** @brief Get total distance traveled. **/
int encoder_get_dx(char encoder);
/** @brief Reset distance counter. **/
void encoder_rst_dx(char encoder);
/** @brief Get time count: The number of encoder reads that have occurred. **/
int encoder_get_tc(void);
/** @brief Reset the time count. **/
void encoder_rst_tc(void);

/** @brief Waits for the next n encoder reading, then returns. **/
void encoder_wait( int nReadings );

/**@}**/ //end group

#endif
